@@ -57,7 +57,7 @@ def validate_server_url(server_url=None):
 
 def _api_call(*args, **kwargs):
   if 'timeout' not in kwargs:
-    kwargs['timeout'] = 30
+    kwargs['timeout'] = 120
   server_url = validate_server_url(kwargs.get('server_url'))
   if 'server_url' in kwargs:
     del kwargs['server_url']
@@ -231,7 +231,7 @@ def transmit_context(visorfile, archive, server_url=None):
       'borg',
       'create',
       '--stats',
-      '--lock-wait', '120',
+      '--lock-wait', '240',
       '--rsh', 'ssh -i %s -o "StrictHostKeyChecking no" -o "IdentitiesOnly=yes"' % f.name,
       'ssh://%s@%s:%s%s::%s' % (
         c['sshUsername'],
@@ -267,6 +267,11 @@ def do_build(args):
   context_dir = find_context_dir(visorfile)
   print('Done sending build context\n')
 
+  buildenvs = {}
+  for x in args.buildenvs:
+    a, b = x.split('=', 1)
+    buildenvs[a] = b
+
   safe_stream_api_call(
     'post',
     'build',
@@ -274,6 +279,7 @@ def do_build(args):
       'archive': archive,
       'visorfileRelpath': os.path.relpath(visorfile, start=context_dir),
       'keepRunning': args.keep_running,
+      'buildenvs': buildenvs,
     },
   )
 
@@ -399,6 +405,7 @@ def main():
 
   build_parser = subparsers.add_parser('build', help='Build a Visorfile')
   build_parser.add_argument('--keep-running', action='store_true')
+  build_parser.add_argument('--build-env', dest='buildenvs', action='append')
   build_parser.add_argument('visorfile', help='The Visorfile to build')
   build_parser.set_defaults(func=do_build)
 
